@@ -339,7 +339,7 @@ if(interpolate.space[i] == TRUE){
 	} else 
 if(interpolate.space[i] == FALSE){
 	if(interpolate.time[i] == TRUE){
-		spread[i] <- sd(c(rec0, rec1))
+		spread[i] <- sd(c(t1, t2))
 		} else 
 	if(interpolate.time[i] == FALSE){
 		spread[i] <- NA
@@ -378,8 +378,8 @@ if(!is.null(pb)) { if(pb$getVal() == iterations) {close(pb)} }
 
 #####################
 ## Print the units ##
-units <- units[is.na(units)==FALSE]
 if(return.units == TRUE){
+units <- units[is.na(units)==FALSE]
 	for(x in 1:length(unique(units))){
 		print(noquote(paste("Units of variable '", unique(variable)[x], "' are ", unique(units)[x], sep='')))
 	}
